Test coverage report: markupmirror.markup.html

# markupmirror.markup.html: 8 total statements, 100.0% covered

Generated: Wed 2012-04-11 05:19 CDT

Source file: /home/buechler/Sites/django-markupmirror/markupmirror/markup/html.py

Stats: 5 executed, 0 missed, 3 excluded, 13 ignored

1. `from django.utils.translation import ugettext_lazy as _`
2. ``
3. `from markupmirror.markup.base import BaseMarkup`
4. `from markupmirror.markup.base import register_markup`
5. ``
6. ``
7. `class HtmlMarkup(BaseMarkup):`
8. `"""Markup pseudo-transformer for HTML content.`
9. ``
10. `This does not transform anything and thus is potentially harmful.`
11. `Use with care.`
12. ``
13. `"""`
14. `codemirror_mode = 'text/html'`
15. `title = _(u"HTML")`
16. ``
17. ``
18. `register_markup(HtmlMarkup)`
19. ``
20. ``
21. `__all__ = ('HtmlMarkup',)`